==> tine20-allinone_2020.03.4.tar.bz2: Crm/js/Crm-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: "Tous les prospects"

, "Default Lead List"
: "Liste de prospects par défaut"

, "The default list for new leads"
: "La liste par défaut pour les nouveaux prospects"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "Le niveau des actions qui vous seront notifiées."

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: "Favoris par défaut"

, "The default favorite which is loaded on crm startup"
: "Le favoris par défaut qui est charge au lancement du GRC"

, "New Lead"
: "Nouveau prospect"

, "Tags"
: "Marqueurs"

, "Lead name"
: "Nom du prospect"

, "Responsible"
: "Responsable"

, "Partner"
: "Partenaire"

, "Customer"
: "Client"

, "Leadstate"
: "État du prospect"

, "Leadtype"
: "Type du prospect"

, "Leadsource"
: "Origine du prospect"

, "Probability"
: "Probabilité"

, "Turnover"
: "Rotation"

, "Estimated end"
: "Fin estimée"

, "Probable Turnover"
: "Rotation probable"

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: "Contacte"

, "CRM Role"
: "Rôle CRM"

, "Tasks"
: "Tâches"

, "No Tasks to display"
: "Pas de tĉhe à afficher"

, "Summary"
: "Résumé"

, "Add a task..."
: "Ajouter un tâche"

, "Due Date"
: "Date prévue"

, "Priority"
: "Priorité"

, "Percent"
: "Pourcent"

, "Status"
: "Statut"

, "Organizer"
: ""

, "Add new {0}"
: "Ajouter un nouveau {0}"

, "Unlink {0}"
: "Délier {0}"

, "Unlink selected {0}"
: "Délier les {0} sélectionnés"

, "Edit {0}"
: "Éditer le {0}"

, "Edit selected {0}"
: "Éditer le {0} sélectionné"

, "Please choose the Lead to add the contacts to"
: "Choisissez le prospect lié aux contacts"

, "Please select the attenders' role"
: "Choisissez le rôle du participant"

, "Lead, Leads"
: [
  "Prospect"
 ,"Prospects"

]
, "Select Lead"
: "Choisissez un prospect"

, "Role"
: "Rôle"

, "Select Role"
: "Choisissez un rôle"

, "Adding {0} contacts to lead"
: "Ajout de {0} contacts au prospect"

, "Phone"
: "Téléphone"

, "Mobile"
: "Portable"

, "Fax"
: "Fax"

, "E-Mail"
: "E-Mail"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: "Début"

, "Change type to Customer"
: "Modifier en client"

, "Change type to Responsible"
: "Modifier en responsable"

, "Change type to Partner"
: "Modifier en partenaire"

, "Change contact type"
: "Modifier le type de contacte"

, "Search for Contacts to add ..."
: "Recherche de contacte à ajouter..."

, "Name"
: "Nom"

, "Address"
: "Adresse"

, "Data"
: "Données"

, "Cellphone"
: "Téléphone (portable)"

, "End"
: "Fin"

, "You do not have the run right for the Tasks application or it is not activated."
: "Vous n'avez pas les droits pour lancer l'application Tâches, ou  celle-ci n'est pas activée."

, "Products"
: "Produits"

, "You do not have the run right for the Sales application or it is not activated."
: "Vous n'avez pas les droits pour lancer l'application Ventes, ou celle-ci n'est pas activée."

, "Enter lead name"
: ""

, "Expected turnover"
: "Rotation attendue"

, "Description"
: "Description"

, "Enter description"
: "Veuillez saisir une description"

, "lead list, lead lists"
: [
  "liste de prospects"
 ,"listes de prospects"

]
, "lead lists"
: "listes de prospects"

, "Quick Search"
: "Recherche rapide"

, "Last Modified Time"
: "Dernière modification"

, "Last Modified By"
: "Modifié par"

, "Creation Time"
: "Date de création"

, "Created By"
: "Créé par"

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: "Produit"

, "Price"
: "Prix"

, "Quantity"
: "Quantité"

, "Search for Products to add ..."
: "Recherche de produits à ajouter"

, "All leads I have read grants for"
: "Tous les prospects auxquels j'ai accès"

, "Last modified by me"
: "Mes dernières modifications"

, "All leads that I have last modified"
: "Prospects que j'ai modifié dernièrement"

, "My leads"
: "Mes prospects"

, "All leads that I am responsible for"
: "Tous les prospects dont je suis responsable"

, "Leads with overdue tasks"
: "Tâches en retard"

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "ouvert"

, "contacted"
: "contacté"

, "waiting for feedback"
: "en attente de retour"

, "quote sent"
: "cotation envoyée"

, "accepted"
: "accepté"

, "lost"
: "perdu"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Revendeur"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: "État"

, "Source"
: "Source"

, "Scheduled end"
: "Fin planifiée"

, "Folder"
: "Dossier"

, "Updated by"
: "Mis à jour par"

, "Updated Fields:"
: "Champs mis à jour :"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Le prospect %s a changé"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Le prospect %s a été créé"

, "Task"
: "Recherche rapide"

, "Lead Data"
: "Données du prospect"

, "End Scheduled"
: "Fin planifiée"

, "Contacts"
: "Contacts"

, "Telephone"
: "Téléphone"

, "Email"
: "Email"

, "low"
: "basse"

, "normal"
: "normale"

, "high"
: "haute"

, "urgent"
: "urgent"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: "gérer les dossiers de prospects partagés"

, "Create new shared lead folders"
: "Créer de nouveaux dossiers de prospects partagés"

, "manage shared leads favorites"
: "gérer les favoris de prospects partagés"

, "Create or update shared leads favorites"
: "Créer ou mettre à jour les favoris de prospects partagés"




, "Lead"
: "Prospect"

, "lead list"
: "liste de prospects"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Crm/js/Crm-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "Client"

, "Partner"
: "Partenaire"

, "Phone"
: "Téléphone"

, "Mobile"
: "Portable"

, "Fax"
: "Fax"

, "E-Mail"
: "E-Mail"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: "Statut"

, "Start"
: "Début"

, "Estimated end"
: "Fin estimée"

, "Leadtype"
: "Type du prospect"

, "Leadsource"
: "Origine du prospect"

, "Tags"
: "Marqueurs"

, "Lead name"
: "Nom du prospect"

, "Responsible"
: "Responsable"

, "Leadstate"
: "État du prospect"

, "Probability"
: "Probabilité"

, "Turnover"
: "Rotation"

, "End"
: "Fin"

, "Probable Turnover"
: "Rotation probable"

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Add new {0}"
: "Ajouter un nouveau {0}"

, "Unlink {0}"
: "Délier {0}"

, "Unlink selected {0}"
: "Délier les {0} sélectionnés"

, "Edit {0}"
: "Éditer le {0}"

, "Edit selected {0}"
: "Éditer le {0} sélectionné"

, "New Lead"
: "Nouveau prospect"

, "Products"
: "Produits"

, "Product"
: "Produit"

, "Description"
: "Description"

, "Price"
: "Prix"

, "Quantity"
: "Quantité"

, "Search for Products to add ..."
: "Recherche de produits à ajouter"

, "1"
: ""

, "Notifications are disabled"
: ""

, "Send Notification?"
: ""

, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "Tasks"
: "Tâches"

, "You do not have the run right for the Tasks application or it is not activated."
: "Vous n'avez pas les droits pour lancer l'application Tâches, ou  celle-ci n'est pas activée."

, "You do not have the run right for the Sales application or it is not activated."
: "Vous n'avez pas les droits pour lancer l'application Ventes, ou celle-ci n'est pas activée."

, "Lead, Leads"
: [
  "Prospect"
 ,"Prospects"

]
, "Enter lead name"
: ""

, "Expected turnover"
: "Rotation attendue"

, "Enter description"
: "Veuillez saisir une description"

, "lead list, lead lists"
: [
  "liste de prospects"
 ,"listes de prospects"

]
, "lead lists"
: "listes de prospects"

, "Quick Search"
: "Recherche rapide"

, "Last Modified Time"
: "Dernière modification"

, "Last Modified By"
: "Modifié par"

, "Creation Time"
: "Date de création"

, "Created By"
: "Créé par"

, "X Lead"
: ""

, "read-only"
: ""

, "Archived"
: ""

, "Contact"
: "Contacte"

, "CRM Role"
: "Rôle CRM"

, "Change type to Customer"
: "Modifier en client"

, "Change type to Responsible"
: "Modifier en responsable"

, "Change type to Partner"
: "Modifier en partenaire"

, "Change contact type"
: "Modifier le type de contacte"

, "Search for Contacts to add ..."
: "Recherche de contacte à ajouter..."

, "Name"
: "Nom"

, "Address"
: "Adresse"

, "Data"
: "Données"

, "Cellphone"
: "Téléphone (portable)"

, "Role"
: "Rôle"

, "Please choose the Lead to add the contacts to"
: "Choisissez le prospect lié aux contacts"

, "Please select the attenders' role"
: "Choisissez le rôle du participant"

, "Select Lead"
: "Choisissez un prospect"

, "Select Role"
: "Choisissez un rôle"

, "Adding {0} contacts to lead"
: "Ajout de {0} contacts au prospect"

, "No Tasks to display"
: "Pas de tĉhe à afficher"

, "Summary"
: "Résumé"

, "Add a task..."
: "Ajouter un tâche"

, "Due Date"
: "Date prévue"

, "Priority"
: "Priorité"

, "Percent"
: "Pourcent"

, "Organizer"
: ""

, "All leads"
: "Tous les prospects"

, "Default Lead List"
: "Liste de prospects par défaut"

, "The default list for new leads"
: "La liste par défaut pour les nouveaux prospects"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "Le niveau des actions qui vous seront notifiées."

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Default Favorite"
: "Favoris par défaut"

, "The default favorite which is loaded on crm startup"
: "Le favoris par défaut qui est charge au lancement du GRC"

, "controls sending notification of Leads"
: ""

, "send notification)description"
: ""

, "send notification to all access container"
: ""

, "send notification to responsible"
: ""

, "send notification to responsible)description"
: ""

, "send notification to customer"
: ""

, "send notification to partner"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "ouvert"

, "contacted"
: "contacté"

, "waiting for feedback"
: "en attente de retour"

, "quote sent"
: "cotation envoyée"

, "accepted"
: "accepté"

, "lost"
: "perdu"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Revendeur"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Lead Notification Confirmation"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead Data"
: "Données du prospect"

, "End Scheduled"
: "Fin planifiée"

, "Contacts"
: "Contacts"

, "Telephone"
: "Téléphone"

, "Email"
: "Email"

, "low"
: "basse"

, "normal"
: "normale"

, "high"
: "haute"

, "urgent"
: "urgent"

, "CSV all data"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "GENDER_Lead"
: ""

, "Show Closed"
: ""

, "Task"
: "Recherche rapide"

, "State"
: "État"

, "Source"
: "Source"

, "Scheduled end"
: "Fin planifiée"

, "Folder"
: "Dossier"

, "Updated by"
: "Mis à jour par"

, "Updated Fields:"
: "Champs mis à jour :"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Le prospect %s a changé"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Le prospect %s a été créé"

, "This Lead state is set to read-only therefore updating this Lead is not possible."
: ""

, "All leads I have read grants for"
: "Tous les prospects auxquels j'ai accès"

, "Last modified by me"
: "Mes dernières modifications"

, "All leads that I have last modified"
: "Prospects que j'ai modifié dernièrement"

, "My leads"
: "Mes prospects"

, "All leads that I am responsible for"
: "Tous les prospects dont je suis responsable"

, "Leads with overdue tasks"
: "Tâches en retard"

, "manage shared lead folders"
: "gérer les dossiers de prospects partagés"

, "Create new shared lead folders"
: "Créer de nouveaux dossiers de prospects partagés"

, "manage shared leads favorites"
: "gérer les favoris de prospects partagés"

, "Create or update shared leads favorites"
: "Créer ou mettre à jour les favoris de prospects partagés"




, "Lead"
: "Prospect"

, "lead list"
: "liste de prospects"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
